"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isUndefined = exports.isShellObject = exports.isShellClass = exports.isFunction = exports.getShellClass = exports.getProviderWrapper = void 0;

var _Shell = require("../Shell");

var _DEFAULT_PROVIDER_WRAPPER = require("./DEFAULT_PROVIDER_WRAPPER");

var _DEFAULT_SHELL = require("./DEFAULT_SHELL");

var _errors = require("./errors");

var isFunction = function isFunction(x) {
  return typeof x === 'function';
};

exports.isFunction = isFunction;

var isUndefined = function isUndefined(x) {
  return typeof x === 'undefined';
};

exports.isUndefined = isUndefined;

var isShellClass = function isShellClass(x) {
  return (x === null || x === void 0 ? void 0 : x.prototype) instanceof _Shell.Shell;
};

exports.isShellClass = isShellClass;

var isShellObject = function isShellObject(x) {
  return x instanceof _Shell.Shell;
};

exports.isShellObject = isShellObject;

var getShellClass = function getShellClass(options) {
  var shellClass = options === null || options === void 0 ? void 0 : options.shellClass;

  if (isUndefined(shellClass)) {
    return _DEFAULT_SHELL.DEFAULT_SHELL;
  }

  (0, _errors.error_if_invalid_shellClass)(shellClass);
  return shellClass;
};

exports.getShellClass = getShellClass;

var getProviderWrapper = function getProviderWrapper(options) {
  var customProviderWrapper = options === null || options === void 0 ? void 0 : options.customProviderWrapper;

  if (isUndefined(customProviderWrapper)) {
    return _DEFAULT_PROVIDER_WRAPPER.DEFAULT_PROVIDER_WRAPPER;
  }

  (0, _errors.error_if_invalid_customProviderWrapper)(customProviderWrapper);
  return customProviderWrapper;
};

exports.getProviderWrapper = getProviderWrapper;